@@ -1,6 +1,8 @@
 import sys
 
 from django.db.models.fields import FieldDoesNotExist
+from django.db.models.options import get_verbose_name
+from django.utils.text import capfirst
 
 from mongoengine.fields import ReferenceField
 
@@ -70,7 +72,7 @@ class DocumentMetaWrapper(object):
         self.app_label = model_module.__name__.split('.')[-2]
         
         if self.verbose_name is None:
-            self.verbose_name = self.object_name
+            self.verbose_name = capfirst(get_verbose_name(self.object_name))
         
         self.verbose_name_raw = self.verbose_name
         
@@ -103,7 +105,7 @@ class DocumentMetaWrapper(object):
                 
             self.document._pk_val = getattr(self.document, self.pk_name)
             # avoid circular import
-            from mongoadmin.util import patch_document
+            from mongodbforms.util import patch_document
             def _get_pk_val(self):
                 return self._pk_val
             patch_document(_get_pk_val, self.document)
